pub enum DependencyTypeError {
EmptyDependencyType,
LeadingOrTrailingSpaces,
}Expand description
Represents an error that can occur when validating a DependencyType value.
This error is used to indicate that a DependencyType value is invalid.
Variants
EmptyDependencyType
Indicates that the DependencyType value is invalid because it is empty.
LeadingOrTrailingSpaces
Indicates that the DependencyType value is invalid because it contains leading or trailing spaces.