SbatchOption

Enum SbatchOption 

pub enum SbatchOption {
Show 109 variants Account(String), AcctgFreq(String), Array(String), Batch(String), Bb(String), Bbf(String), Begin(String), Chdir(String), ClusterConstraint(String), Clusters(String), Comment(String), Constraint(String), Container(String), ContainerID(String), Contiguous, CoreSpec(String), CoresPerSocket(String), CPUFreq(String), CPUsPerGPU(String), CPUsPerTask(String), Deadline(String), DelayBoot(String), Dependency(String), Distribution(String), Error(String), Exclude(String), Exclusive(Option<String>), Export(String), ExportFile(String), Extra(String), ExtraNodeInfo(String), GetUserEnv(Option<String>), GID(String), GPUBind(String), GPUFreq(String), GPUs(String), GPUsPerNode(String), GPUsPerSocket(String), GPUsPerTask(String), Gres(String), GresFlags(String), Help, Hint(String), Hold, IgnorePbs, Input(String), JobName(String), KillOnInvalidDep(String), Licenses(String), MailType(String), MailUser(String), McsLabel(String), Mem(String), MemBind(String), MemPerCPU(String), MemPerGPU(String), MinCPUs(String), Network(String), Nice(Option<String>), NoKill(Option<String>), NoRequeue, NodeFile(String), NodeList(String), Nodes(String), NTasks(String), NTasksPerCore(String), NTasksPerGPU(String), NTasksPerNode(String), NTasksPerSocket(String), OOMKillStep(Option<String>), OpenMode(String), Output(String), Overcommit, Oversubscribe, Parsable, Partition(String), Prefer(String), Priority(String), Profile(String), Propagate(Option<String>), Qos(String), Quiet, Reboot, Requeue, Reservation(String), ResvPorts(Option<String>), Segment(String), Signal(String), SocketsPerNode(String), SpreadJob, Stepmgr, Switches(String), TestOnly, ThreadSpec(String), ThreadsPerCore(String), Time(String), TimeMin(String), Tmp(String), TresBind(String), TresPerTask(String), UID(String), Usage, UseMinNodes, Verbose, Version, Wait, WaitAllNodes(String), WCKey(String), Wrap(String),
}
Represents an sbatch option

For a full description of the sbatch options, see the slurm documentation: https://slurm.schedmd.com/sbatch.html The SbatchOption enum variants store Nothing, String, or Option<String> where appropriate. For more complex options, such as --dependency, the helper Dependency struct can be used to format the string.

Variants



Account(String)



AcctgFreq(String)



Array(String)



Batch(String)



Bb(String)



Bbf(String)



Begin(String)



Chdir(String)



ClusterConstraint(String)



Clusters(String)



Comment(String)



Constraint(String)



Container(String)



ContainerID(String)



Contiguous



CoreSpec(String)



CoresPerSocket(String)



CPUFreq(String)



CPUsPerGPU(String)



CPUsPerTask(String)



Deadline(String)



DelayBoot(String)



Dependency(String)



Distribution(String)



Error(String)



Exclude(String)



Exclusive(Option<String>)



Export(String)



ExportFile(String)



Extra(String)



ExtraNodeInfo(String)



GetUserEnv(Option<String>)



GID(String)



GPUBind(String)



GPUFreq(String)



GPUs(String)



GPUsPerNode(String)



GPUsPerSocket(String)



GPUsPerTask(String)



Gres(String)



GresFlags(String)



Help



Hint(String)



Hold



IgnorePbs



Input(String)



JobName(String)



KillOnInvalidDep(String)



Licenses(String)



MailType(String)



MailUser(String)



McsLabel(String)



Mem(String)



MemBind(String)



MemPerCPU(String)



MemPerGPU(String)



MinCPUs(String)



Network(String)



Nice(Option<String>)



NoKill(Option<String>)



NoRequeue



NodeFile(String)



NodeList(String)



Nodes(String)



NTasks(String)



NTasksPerCore(String)



NTasksPerGPU(String)



NTasksPerNode(String)



NTasksPerSocket(String)



OOMKillStep(Option<String>)



OpenMode(String)



Output(String)



Overcommit



Oversubscribe



Parsable



Partition(String)



Prefer(String)



Priority(String)



Profile(String)



Propagate(Option<String>)



Qos(String)



Quiet



Reboot



Requeue



Reservation(String)



ResvPorts(Option<String>)



Segment(String)



Signal(String)



SocketsPerNode(String)



SpreadJob



Stepmgr



Switches(String)



TestOnly



ThreadSpec(String)



ThreadsPerCore(String)



Time(String)



TimeMin(String)



Tmp(String)



TresBind(String)



TresPerTask(String)



UID(String)



Usage



UseMinNodes



Verbose



Version



Wait



WaitAllNodes(String)



WCKey(String)



Wrap(String)

Implementations

Source

impl SbatchOption

pub fn validate(&self) -> Result<(), SbatchOptionError>

Validates the sbatch option.

Returns

This function returns Ok(()) if the sbatch option is valid, otherwise it returns a SbatchOptionError.

Errors

This function returns a SbatchOptionError if the sbatch option is invalid. The following are considered invalid:

  • An empty string
  • A string that contains leading or trailing spaces
Examples
use sbatch_rs::SbatchOption;

// Valid: mapped to `--account=account`
let sbatch_option = SbatchOption::Account("account".to_string());
assert!(sbatch_option.validate().is_ok());

// Invalid: empty string
let sbatch_option = SbatchOption::Account("".to_string());
assert!(sbatch_option.validate().is_err());

// Invalid: leading or trailing spaces
let sbatch_option = SbatchOption::Account(" account ".to_string());
assert!(sbatch_option.validate().is_err());